"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateClientSecret = generateClientSecret;
exports.default = Apple;

var _jose = require("jose");

var _crypto = require("crypto");

async function generateClientSecret(components, expires_in = 86400 * 180) {
  const {
    keyId,
    teamId,
    privateKey,
    clientId
  } = components;
  const expiresAt = Math.ceil(Date.now() / 1000) + expires_in;
  return await new _jose.SignJWT({}).setAudience("https://appleid.apple.com").setIssuer(teamId).setIssuedAt().setExpirationTime(expiresAt).setSubject(clientId).setProtectedHeader({
    alg: "ES256",
    kid: keyId
  }).sign((0, _crypto.createPrivateKey)(privateKey.replace(/\\n/g, "\n")));
}

function Apple(options) {
  return {
    id: "apple",
    name: "Apple",
    type: "oauth",
    wellKnown: "https://appleid.apple.com/.well-known/openid-configuration",
    authorization: {
      params: {
        scope: "name email",
        response_mode: "form_post"
      }
    },
    idToken: true,

    profile(profile) {
      return {
        id: profile.sub,
        name: profile.name,
        email: profile.email,
        image: null
      };
    },

    checks: ["pkce"],
    options
  };
}